@@ -14,14 +14,20 @@
 #include <poll.h>
 
 #include "duktape.h"
+#include "c_eventloop.h"
 
-#define  MAX_TIMERS             4096     /* this is quite excessive for embedded use, but good for testing */
+#if !defined(DUKTAPE_EVENTLOOP_DEBUG)
+#define DUKTAPE_EVENTLOOP_DEBUG 0       /* set to 1 to debug with printf */
+#endif
+
+#define  TIMERS_SLOT_NAME       "eventTimers"
 #define  MIN_DELAY              1.0
 #define  MIN_WAIT               1.0
 #define  MAX_WAIT               60000.0
-#define  MAX_EXPIRYS            10
+#define  MAX_EXPIRIES           10
 
 #define  MAX_FDS                256
+#define  MAX_TIMERS             4096     /* this is quite excessive for embedded use, but good for testing */
 
 typedef struct {
 	int64_t id;       /* numeric ID (returned from e.g. setTimeout); zero if unused */
@@ -103,7 +109,7 @@ static void bubble_last_timer(void) {
 
 static void expire_timers(duk_context *ctx) {
 	ev_timer *t;
-	int sanity = MAX_EXPIRYS;
+	int sanity = MAX_EXPIRIES;
 	double now;
 	int rc;
 
@@ -113,7 +119,7 @@ static void expire_timers(duk_context *ctx) {
 	 */
 
 	duk_push_global_stash(ctx);
-	duk_get_prop_string(ctx, -1, "eventTimers");
+	duk_get_prop_string(ctx, -1, TIMERS_SLOT_NAME);
 
 	/* [ ... stash eventTimers ] */
 
@@ -125,7 +131,7 @@ static void expire_timers(duk_context *ctx) {
 		 */
 
 		if (exit_requested) {
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 			fprintf(stderr, "exit requested, exiting timer expiry loop\n");
 			fflush(stderr);
 #endif
@@ -168,7 +174,7 @@ static void expire_timers(duk_context *ctx) {
 		 *  need to worry about the timer's offset changing on the timer list.
 		 */
 
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 		fprintf(stderr, "calling user callback for timer id %d\n", (int) t->id);
 		fflush(stderr);
 #endif
@@ -177,7 +183,7 @@ static void expire_timers(duk_context *ctx) {
 		duk_get_prop(ctx, -2);  /* -> [ ... stash eventTimers func ] */
 		rc = duk_pcall(ctx, 0 /*nargs*/);  /* -> [ ... stash eventTimers retval ] */
 		if (rc != 0) {
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 			fprintf(stderr, "timer callback failed for timer %d: %s\n", (int) t->id, duk_to_string(ctx, -1));
 			fflush(stderr);
 #endif
@@ -186,7 +192,7 @@ static void expire_timers(duk_context *ctx) {
 
 		if (t->removed) {
 			/* One-shot timer (always removed) or removed by user callback. */
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 			fprintf(stderr, "deleting callback state for timer %d\n", (int) t->id);
 			fflush(stderr);
 #endif
@@ -196,7 +202,7 @@ static void expire_timers(duk_context *ctx) {
 			/* Interval timer, not removed by user callback.  Queue back to
 			 * timer list and bubble to its final sorted position.
 			 */
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 			fprintf(stderr, "queueing timer %d back into active list\n", (int) t->id);
 			fflush(stderr);
 #endif
@@ -226,7 +232,7 @@ static void compact_poll_list(void) {
 		struct pollfd *pfd = poll_list + i;
 		if (pfd->fd == 0) {
 			/* keep output index the same */
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 			fprintf(stderr, "remove pollfd (index %d): fd=%d, events=%d, revents=%d\n",
 			        i, pfd->fd, pfd->events, pfd->revents),
 			fflush(stderr);
@@ -234,7 +240,7 @@ static void compact_poll_list(void) {
 
 			continue;
 		}
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 		fprintf(stderr, "keep pollfd (index %d -> %d): fd=%d, events=%d, revents=%d\n",
 		        i, j, pfd->fd, pfd->events, pfd->revents),
 		fflush(stderr);
@@ -266,7 +272,7 @@ duk_ret_t eventloop_run(duk_context *ctx, void *udata) {
 
 	(void) udata;
 
-	/* The Ecmascript poll handler is passed through EventLoop.fdPollHandler
+	/* The ECMAScript poll handler is passed through EventLoop.fdPollHandler
 	 * which c_eventloop.js sets before we come here.
 	 */
 	duk_push_global_object(ctx);
@@ -287,7 +293,7 @@ duk_ret_t eventloop_run(duk_context *ctx, void *udata) {
 		 */
 
 		if (exit_requested) {
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 			fprintf(stderr, "exit requested, exiting event loop\n");
 			fflush(stderr);
 #endif
@@ -317,7 +323,7 @@ duk_ret_t eventloop_run(duk_context *ctx, void *udata) {
 			timeout = (int) diff;  /* clamping ensures that fits */
 		} else {
 			if (poll_count == 0) {
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 				fprintf(stderr, "no timers and no sockets to poll, exiting\n");
 				fflush(stderr);
 #endif
@@ -330,13 +336,13 @@ duk_ret_t eventloop_run(duk_context *ctx, void *udata) {
 		 *  Poll for activity or timeout.
 		 */
 
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 		fprintf(stderr, "going to poll, timeout %d ms, pollfd count %d\n", timeout, poll_count);
 		fflush(stderr);
 #endif
 
 		rc = poll(poll_list, poll_count, timeout);
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 		fprintf(stderr, "poll rc: %d\n", rc);
 		fflush(stderr);
 #endif
@@ -350,7 +356,7 @@ duk_ret_t eventloop_run(duk_context *ctx, void *udata) {
 
 		/*
 		 *  Check socket activity, handle all sockets.  Handling is offloaded to
-		 *  Ecmascript code (fd + revents).
+		 *  ECMAScript code (fd + revents).
 		 *
 		 *  If FDs are removed from the poll list while we're processing callbacks,
 		 *  the entries are simply marked unused (fd set to 0) without actually
@@ -368,7 +374,7 @@ duk_ret_t eventloop_run(duk_context *ctx, void *udata) {
 			}
 
 			if (pfd->revents) {
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 				fprintf(stderr, "fd %d has revents: %d\n", (int) pfd->fd, (int) pfd->revents);
 				fflush(stderr);
 #endif
@@ -378,7 +384,7 @@ duk_ret_t eventloop_run(duk_context *ctx, void *udata) {
 				duk_push_int(ctx, pfd->revents);
 				rc = duk_pcall_method(ctx, 2 /*nargs*/);
 				if (rc) {
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 					fprintf(stderr, "fd callback failed for fd %d: %s\n", (int) pfd->fd, duk_to_string(ctx, -1));
 					fflush(stderr);
 #endif
@@ -441,7 +447,7 @@ static int create_timer(duk_context *ctx) {
 	/* Finally, register the callback to the global stash 'eventTimers' object. */
 
 	duk_push_global_stash(ctx);
-	duk_get_prop_string(ctx, -1, "eventTimers");  /* -> [ func delay oneshot stash eventTimers ] */
+	duk_get_prop_string(ctx, -1, TIMERS_SLOT_NAME);  /* -> [ func delay oneshot stash eventTimers ] */
 	duk_push_number(ctx, (double) timer_id);
 	duk_dup(ctx, 0);
 	duk_put_prop(ctx, -3);  /* eventTimers[timer_id] = callback */
@@ -449,7 +455,7 @@ static int create_timer(duk_context *ctx) {
 	/* Return timer id. */
 
 	duk_push_number(ctx, (double) timer_id);
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 	fprintf(stderr, "created timer id: %d\n", (int) timer_id);
 	fflush(stderr);
 #endif
@@ -483,7 +489,7 @@ static int delete_timer(duk_context *ctx) {
 	if (t->id == timer_id) {
 		t->removed = 1;
 		duk_push_true(ctx);
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 		fprintf(stderr, "deleted expiring timer id: %d\n", (int) timer_id);
 		fflush(stderr);
 #endif
@@ -514,11 +520,11 @@ static int delete_timer(duk_context *ctx) {
 			 */
 
 			duk_push_global_stash(ctx);
-			duk_get_prop_string(ctx, -1, "eventTimers");  /* -> [ timer_id stash eventTimers ] */
+			duk_get_prop_string(ctx, -1, TIMERS_SLOT_NAME);  /* -> [ timer_id stash eventTimers ] */
 			duk_push_number(ctx, (double) timer_id);
 			duk_del_prop(ctx, -2);  /* delete eventTimers[timer_id] */
 
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 			fprintf(stderr, "deleted timer id: %d\n", (int) timer_id);
 			fflush(stderr);
 #endif
@@ -526,7 +532,7 @@ static int delete_timer(duk_context *ctx) {
 		}
 	}
 
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 	if (!found) {
 		fprintf(stderr, "trying to delete timer id %d, but not found; ignoring\n", (int) timer_id);
 		fflush(stderr);
@@ -543,7 +549,7 @@ static int listen_fd(duk_context *ctx) {
 	int i, n;
 	struct pollfd *pfd;
 
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 	fprintf(stderr, "listen_fd: fd=%d, events=%d\n", fd, events);
 	fflush(stderr);
 #endif
@@ -553,7 +559,7 @@ static int listen_fd(duk_context *ctx) {
 	for (i = 0; i < n; i++) {
 		pfd = poll_list + i;
 		if (pfd->fd == fd) {
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 			fprintf(stderr, "listen_fd: fd found at index %d\n", i);
 			fflush(stderr);
 #endif
@@ -568,7 +574,7 @@ static int listen_fd(duk_context *ctx) {
 	}
 
 	/* not found, append to list */
-#if 0
+#if DUKTAPE_EVENTLOOP_DEBUG > 0
 	fprintf(stderr, "listen_fd: fd not found on list, add new entry\n");
 	fflush(stderr);
 #endif
@@ -615,6 +621,6 @@ void eventloop_register(duk_context *ctx) {
 	/* Initialize global stash 'eventTimers'. */
 	duk_push_global_stash(ctx);
 	duk_push_object(ctx);
-	duk_put_prop_string(ctx, -2, "eventTimers");
+	duk_put_prop_string(ctx, -2, TIMERS_SLOT_NAME);
 	duk_pop(ctx);
 }
