@@ -58,7 +58,8 @@ DUK_LOCAL DUK_NOINLINE_PERF DUK_COLD void *duk__heap_mem_alloc_slowpath(duk_heap
 		res = heap->alloc_func(heap->heap_udata, size);
 		if (res != NULL) {
 			DUK_D(DUK_DPRINT("duk_heap_mem_alloc() succeeded after gc (pass %ld), alloc size %ld",
-			                 (long) (i + 1), (long) size));
+			                 (long) (i + 1),
+			                 (long) size));
 			return res;
 		}
 	}
@@ -102,7 +103,7 @@ DUK_INTERNAL DUK_INLINE_PERF DUK_HOT void *duk_heap_mem_alloc(duk_heap *heap, du
 		return res;
 	}
 
- slowpath:
+slowpath:
 
 	if (size == 0) {
 		DUK_D(DUK_DPRINT("first alloc attempt returned NULL for zero size alloc, use slow path to deal with it"));
@@ -177,13 +178,7 @@ DUK_LOCAL DUK_NOINLINE_PERF DUK_COLD void *duk__heap_mem_realloc_slowpath(duk_he
 	/* ptr may be NULL */
 	DUK_ASSERT_DISABLE(newsize >= 0);
 
-	/* Newsize was 0 and realloc() returned NULL, this has the semantics
-	 * of free(oldptr), i.e. memory was successfully freed.
-	 */
-	if (newsize == 0) {
-		DUK_D(DUK_DPRINT("zero size realloc in slow path, return NULL"));
-		return NULL;
-	}
+	/* Unlike for malloc(), zero size NULL result check happens at the call site. */
 
 	DUK_D(DUK_DPRINT("first realloc attempt failed, attempt to gc and retry"));
 
@@ -214,11 +209,11 @@ DUK_LOCAL DUK_NOINLINE_PERF DUK_COLD void *duk__heap_mem_realloc_slowpath(duk_he
 
 		duk_heap_mark_and_sweep(heap, flags);
 
-		DUK_ASSERT(newsize > 0);
 		res = heap->realloc_func(heap->heap_udata, ptr, newsize);
-		if (res || newsize == 0) {
+		if (res != NULL || newsize == 0) {
 			DUK_D(DUK_DPRINT("duk_heap_mem_realloc() succeeded after gc (pass %ld), alloc size %ld",
-			                 (long) (i + 1), (long) newsize));
+			                 (long) (i + 1),
+			                 (long) newsize));
 			return res;
 		}
 	}
@@ -238,7 +233,7 @@ DUK_INTERNAL DUK_INLINE_PERF DUK_HOT void *duk_heap_mem_realloc(duk_heap *heap,
 #if defined(DUK_USE_VOLUNTARY_GC)
 	/* Voluntary periodic GC (if enabled). */
 	if (DUK_UNLIKELY(--(heap)->ms_trigger_counter < 0)) {
-		goto slowpath;
+		goto gc_retry;
 	}
 #endif
 
@@ -250,22 +245,22 @@ DUK_INTERNAL DUK_INLINE_PERF DUK_HOT void *duk_heap_mem_realloc(duk_heap *heap,
 		DUK_DDD(DUK_DDDPRINT("gc torture enabled, pretend that first realloc attempt fails"));
 		res = NULL;
 		DUK_UNREF(res);
-		goto slowpath;
+		goto gc_retry;
 	}
 #endif
 
 	res = heap->realloc_func(heap->heap_udata, ptr, newsize);
-	if (DUK_LIKELY(res != NULL)) {
+	if (DUK_LIKELY(res != NULL) || newsize == 0) {
+		if (res != NULL && newsize == 0) {
+			DUK_DD(DUK_DDPRINT("first realloc attempt returned NULL for zero size realloc, accept and return NULL"));
+		}
 		return res;
-	}
-
- slowpath:
-
-	if (newsize == 0) {
-		DUK_D(DUK_DPRINT("first realloc attempt returned NULL for zero size realloc, use slow path to deal with it"));
 	} else {
-		DUK_D(DUK_DPRINT("first realloc attempt failed, attempt to gc and retry"));
+		goto gc_retry;
 	}
+	/* Never here. */
+
+gc_retry:
 	return duk__heap_mem_realloc_slowpath(heap, ptr, newsize);
 }
 
@@ -276,7 +271,10 @@ DUK_INTERNAL DUK_INLINE_PERF DUK_HOT void *duk_heap_mem_realloc(duk_heap *heap,
  */
 
 /* Slow path: voluntary GC triggered, first realloc attempt failed, or zero size. */
-DUK_LOCAL DUK_NOINLINE_PERF DUK_COLD void *duk__heap_mem_realloc_indirect_slowpath(duk_heap *heap, duk_mem_getptr cb, void *ud, duk_size_t newsize) {
+DUK_LOCAL DUK_NOINLINE_PERF DUK_COLD void *duk__heap_mem_realloc_indirect_slowpath(duk_heap *heap,
+                                                                                   duk_mem_getptr cb,
+                                                                                   void *ud,
+                                                                                   duk_size_t newsize) {
 	void *res;
 	duk_small_int_t i;
 
@@ -284,10 +282,7 @@ DUK_LOCAL DUK_NOINLINE_PERF DUK_COLD void *duk__heap_mem_realloc_indirect_slowpa
 	DUK_ASSERT(heap->realloc_func != NULL);
 	DUK_ASSERT_DISABLE(newsize >= 0);
 
-	if (newsize == 0) {
-		DUK_D(DUK_DPRINT("zero size indirect realloc in slow path, return NULL"));
-		return NULL;
-	}
+	/* Unlike for malloc(), zero size NULL result check happens at the call site. */
 
 	DUK_D(DUK_DPRINT("first indirect realloc attempt failed, attempt to gc and retry"));
 
@@ -329,7 +324,8 @@ DUK_LOCAL DUK_NOINLINE_PERF DUK_COLD void *duk__heap_mem_realloc_indirect_slowpa
 		ptr_post = cb(heap, ud);
 		if (ptr_pre != ptr_post) {
 			DUK_DD(DUK_DDPRINT("realloc base pointer changed by mark-and-sweep: %p -> %p",
-			                   (void *) ptr_pre, (void *) ptr_post));
+			                   (void *) ptr_pre,
+			                   (void *) ptr_post));
 		}
 #endif
 
@@ -337,11 +333,11 @@ DUK_LOCAL DUK_NOINLINE_PERF DUK_COLD void *duk__heap_mem_realloc_indirect_slowpa
 		 * The pointer being reallocated may change after every mark-and-sweep.
 		 */
 
-		DUK_ASSERT(newsize > 0);
 		res = heap->realloc_func(heap->heap_udata, cb(heap, ud), newsize);
-		if (res || newsize == 0) {
+		if (res != NULL || newsize == 0) {
 			DUK_D(DUK_DPRINT("duk_heap_mem_realloc_indirect() succeeded after gc (pass %ld), alloc size %ld",
-			                 (long) (i + 1), (long) newsize));
+			                 (long) (i + 1),
+			                 (long) newsize));
 			return res;
 		}
 	}
@@ -350,7 +346,10 @@ DUK_LOCAL DUK_NOINLINE_PERF DUK_COLD void *duk__heap_mem_realloc_indirect_slowpa
 	return NULL;
 }
 
-DUK_INTERNAL DUK_INLINE_PERF DUK_HOT void *duk_heap_mem_realloc_indirect(duk_heap *heap, duk_mem_getptr cb, void *ud, duk_size_t newsize) {
+DUK_INTERNAL DUK_INLINE_PERF DUK_HOT void *duk_heap_mem_realloc_indirect(duk_heap *heap,
+                                                                         duk_mem_getptr cb,
+                                                                         void *ud,
+                                                                         duk_size_t newsize) {
 	void *res;
 
 	DUK_ASSERT(heap != NULL);
@@ -360,7 +359,7 @@ DUK_INTERNAL DUK_INLINE_PERF DUK_HOT void *duk_heap_mem_realloc_indirect(duk_hea
 #if defined(DUK_USE_VOLUNTARY_GC)
 	/* Voluntary periodic GC (if enabled). */
 	if (DUK_UNLIKELY(--(heap)->ms_trigger_counter < 0)) {
-		goto slowpath;
+		goto gc_retry;
 	}
 #endif
 
@@ -372,22 +371,23 @@ DUK_INTERNAL DUK_INLINE_PERF DUK_HOT void *duk_heap_mem_realloc_indirect(duk_hea
 		DUK_DDD(DUK_DDDPRINT("gc torture enabled, pretend that first indirect realloc attempt fails"));
 		res = NULL;
 		DUK_UNREF(res);
-		goto slowpath;
+		goto gc_retry;
 	}
 #endif
 
 	res = heap->realloc_func(heap->heap_udata, cb(heap, ud), newsize);
-	if (DUK_LIKELY(res != NULL)) {
+	if (DUK_LIKELY(res != NULL) || newsize == 0) {
+		if (res != NULL && newsize == 0) {
+			DUK_DD(DUK_DDPRINT(
+			    "first indirect realloc attempt returned NULL for zero size realloc, accept and return NULL"));
+		}
 		return res;
-	}
-
- slowpath:
-
-	if (newsize == 0) {
-		DUK_D(DUK_DPRINT("first indirect realloc attempt returned NULL for zero size realloc, use slow path to deal with it"));
 	} else {
-		DUK_D(DUK_DPRINT("first indirect realloc attempt failed, attempt to gc and retry"));
+		goto gc_retry;
 	}
+	/* Never here. */
+
+gc_retry:
 	return duk__heap_mem_realloc_indirect_slowpath(heap, cb, ud, newsize);
 }
 
