@@ -7,29 +7,25 @@
 DUK_INTERNAL void duk_hthread_terminate(duk_hthread *thr) {
 	DUK_ASSERT(thr != NULL);
 
-	/* Order of unwinding is important */
-
-	duk_hthread_catchstack_unwind(thr, 0);
-	duk_hthread_callstack_unwind(thr, 0);  /* side effects, possibly errors */
+	while (thr->callstack_curr != NULL) {
+		duk_hthread_activation_unwind_norz(thr);
+	}
 
 	thr->valstack_bottom = thr->valstack;
-	duk_set_top((duk_context *) thr, 0);  /* unwinds valstack, updating refcounts */
+	duk_set_top(thr, 0); /* unwinds valstack, updating refcounts */
 
 	thr->state = DUK_HTHREAD_STATE_TERMINATED;
 
 	/* Here we could remove references to built-ins, but it may not be
 	 * worth the effort because built-ins are quite likely to be shared
 	 * with another (unterminated) thread, and terminated threads are also
-	 * usually garbage collected quite quickly.  Also, doing DECREFs
-	 * could trigger finalization, which would run on the current thread
-	 * and have access to only some of the built-ins.  Garbage collection
-	 * deals with this correctly already.
+	 * usually garbage collected quite quickly.
+	 *
+	 * We could also shrink the value stack here, but that also may not
+	 * be worth the effort for the same reason.
 	 */
 
-	/* XXX: Shrink the stacks to minimize memory usage?  May not
-	 * be worth the effort because terminated threads are usually
-	 * garbage collected quite soon.
-	 */
+	DUK_REFZERO_CHECK_SLOW(thr);
 }
 
 #if defined(DUK_USE_DEBUGGER_SUPPORT)
@@ -47,7 +43,7 @@ DUK_INTERNAL duk_uint_fast32_t duk_hthread_get_act_curr_pc(duk_hthread *thr, duk
 	}
 	return 0;
 }
-#endif  /* DUK_USE_DEBUGGER_SUPPORT */
+#endif /* DUK_USE_DEBUGGER_SUPPORT */
 
 DUK_INTERNAL duk_uint_fast32_t duk_hthread_get_act_prev_pc(duk_hthread *thr, duk_activation *act) {
 	duk_instr_t *bcode;
