@@ -30,9 +30,9 @@ DUK_EXTERNAL duk_bool_t duk_get_prop(duk_hthread *thr, duk_idx_t obj_idx) {
 	DUK_ASSERT(rc == 0 || rc == 1);
 	/* a value is left on stack regardless of rc */
 
-	duk_remove_m2(thr);  /* remove key */
+	duk_remove_m2(thr); /* remove key */
 	DUK_ASSERT(duk_is_undefined(thr, -1) || rc == 1);
-	return rc;  /* 1 if property found, 0 otherwise */
+	return rc; /* 1 if property found, 0 otherwise */
 }
 
 DUK_EXTERNAL duk_bool_t duk_get_prop_string(duk_hthread *thr, duk_idx_t obj_idx, const char *key) {
@@ -77,7 +77,7 @@ DUK_EXTERNAL duk_bool_t duk_get_prop_heapptr(duk_hthread *thr, duk_idx_t obj_idx
 	DUK_ASSERT_API_ENTRY(thr);
 
 	obj_idx = duk_require_normalize_index(thr, obj_idx);
-	(void) duk_push_heapptr(thr, ptr);  /* NULL -> 'undefined' */
+	(void) duk_push_heapptr(thr, ptr); /* NULL -> 'undefined' */
 	return duk_get_prop(thr, obj_idx);
 }
 
@@ -91,11 +91,13 @@ DUK_INTERNAL duk_bool_t duk_get_prop_stridx(duk_hthread *thr, duk_idx_t obj_idx,
 }
 
 DUK_INTERNAL duk_bool_t duk_get_prop_stridx_short_raw(duk_hthread *thr, duk_uint_t packed_args) {
-	return duk_get_prop_stridx(thr, (duk_idx_t) (duk_int16_t) (packed_args >> 16),
-	                                (duk_small_uint_t) (packed_args & 0xffffUL));
+	return duk_get_prop_stridx(thr, (duk_idx_t) (duk_int16_t) (packed_args >> 16), (duk_small_uint_t) (packed_args & 0xffffUL));
 }
 
-DUK_INTERNAL duk_bool_t duk_get_prop_stridx_boolean(duk_hthread *thr, duk_idx_t obj_idx, duk_small_uint_t stridx, duk_bool_t *out_has_prop) {
+DUK_INTERNAL duk_bool_t duk_get_prop_stridx_boolean(duk_hthread *thr,
+                                                    duk_idx_t obj_idx,
+                                                    duk_small_uint_t stridx,
+                                                    duk_bool_t *out_has_prop) {
 	duk_bool_t rc;
 
 	DUK_ASSERT_API_ENTRY(thr);
@@ -140,7 +142,7 @@ DUK_INTERNAL duk_bool_t duk_xget_owndataprop(duk_hthread *thr, duk_idx_t obj_idx
 	}
 
 	duk_push_tval(thr, tv_val);
-	duk_remove_m2(thr);  /* remove key */
+	duk_remove_m2(thr); /* remove key */
 
 	return 1;
 }
@@ -155,7 +157,8 @@ DUK_INTERNAL duk_bool_t duk_xget_owndataprop_stridx(duk_hthread *thr, duk_idx_t
 }
 
 DUK_INTERNAL duk_bool_t duk_xget_owndataprop_stridx_short_raw(duk_hthread *thr, duk_uint_t packed_args) {
-	return duk_xget_owndataprop_stridx(thr, (duk_idx_t) (duk_int16_t) (packed_args >> 16),
+	return duk_xget_owndataprop_stridx(thr,
+	                                   (duk_idx_t) (duk_int16_t) (packed_args >> 16),
 	                                   (duk_small_uint_t) (packed_args & 0xffffUL));
 }
 
@@ -174,8 +177,7 @@ DUK_LOCAL duk_bool_t duk__put_prop_shared(duk_hthread *thr, duk_idx_t obj_idx, d
 	/* Key and value indices are either (-2, -1) or (-1, -2).  Given idx_key,
 	 * idx_val is always (idx_key ^ 0x01).
 	 */
-	DUK_ASSERT((idx_key == -2 && (idx_key ^ 1) == -1) ||
-	           (idx_key == -1 && (idx_key ^ 1) == -2));
+	DUK_ASSERT((idx_key == -2 && (idx_key ^ 1) == -1) || (idx_key == -1 && (idx_key ^ 1) == -2));
 	/* XXX: Direct access; faster validation. */
 	tv_obj = duk_require_tval(thr, obj_idx);
 	tv_key = duk_require_tval(thr, idx_key);
@@ -185,8 +187,8 @@ DUK_LOCAL duk_bool_t duk__put_prop_shared(duk_hthread *thr, duk_idx_t obj_idx, d
 	rc = duk_hobject_putprop(thr, tv_obj, tv_key, tv_val, throw_flag);
 	DUK_ASSERT(rc == 0 || rc == 1);
 
-	duk_pop_2(thr);  /* remove key and value */
-	return rc;  /* 1 if property found, 0 otherwise */
+	duk_pop_2(thr); /* remove key and value */
+	return rc; /* 1 if property found, 0 otherwise */
 }
 
 DUK_EXTERNAL duk_bool_t duk_put_prop(duk_hthread *thr, duk_idx_t obj_idx) {
@@ -240,11 +242,10 @@ DUK_EXTERNAL duk_bool_t duk_put_prop_heapptr(duk_hthread *thr, duk_idx_t obj_idx
 	DUK_ASSERT_API_ENTRY(thr);
 
 	obj_idx = duk_require_normalize_index(thr, obj_idx);
-	(void) duk_push_heapptr(thr, ptr);  /* NULL -> 'undefined' */
+	(void) duk_push_heapptr(thr, ptr); /* NULL -> 'undefined' */
 	return duk__put_prop_shared(thr, obj_idx, -1);
 }
 
-
 DUK_INTERNAL duk_bool_t duk_put_prop_stridx(duk_hthread *thr, duk_idx_t obj_idx, duk_small_uint_t stridx) {
 	DUK_ASSERT_API_ENTRY(thr);
 	DUK_ASSERT_STRIDX_VALID(stridx);
@@ -255,8 +256,7 @@ DUK_INTERNAL duk_bool_t duk_put_prop_stridx(duk_hthread *thr, duk_idx_t obj_idx,
 }
 
 DUK_INTERNAL duk_bool_t duk_put_prop_stridx_short_raw(duk_hthread *thr, duk_uint_t packed_args) {
-	return duk_put_prop_stridx(thr, (duk_idx_t) (duk_int16_t) (packed_args >> 16),
-	                                (duk_small_uint_t) (packed_args & 0xffffUL));
+	return duk_put_prop_stridx(thr, (duk_idx_t) (duk_int16_t) (packed_args >> 16), (duk_small_uint_t) (packed_args & 0xffffUL));
 }
 
 DUK_EXTERNAL duk_bool_t duk_del_prop(duk_hthread *thr, duk_idx_t obj_idx) {
@@ -278,7 +278,7 @@ DUK_EXTERNAL duk_bool_t duk_del_prop(duk_hthread *thr, duk_idx_t obj_idx) {
 	rc = duk_hobject_delprop(thr, tv_obj, tv_key, throw_flag);
 	DUK_ASSERT(rc == 0 || rc == 1);
 
-	duk_pop(thr);  /* remove key */
+	duk_pop(thr); /* remove key */
 	return rc;
 }
 
@@ -324,7 +324,7 @@ DUK_EXTERNAL duk_bool_t duk_del_prop_heapptr(duk_hthread *thr, duk_idx_t obj_idx
 	DUK_ASSERT_API_ENTRY(thr);
 
 	obj_idx = duk_require_normalize_index(thr, obj_idx);
-	(void) duk_push_heapptr(thr, ptr);  /* NULL -> 'undefined' */
+	(void) duk_push_heapptr(thr, ptr); /* NULL -> 'undefined' */
 	return duk_del_prop(thr, obj_idx);
 }
 
@@ -361,8 +361,8 @@ DUK_EXTERNAL duk_bool_t duk_has_prop(duk_hthread *thr, duk_idx_t obj_idx) {
 	rc = duk_hobject_hasprop(thr, tv_obj, tv_key);
 	DUK_ASSERT(rc == 0 || rc == 1);
 
-	duk_pop(thr);  /* remove key */
-	return rc;  /* 1 if property found, 0 otherwise */
+	duk_pop(thr); /* remove key */
+	return rc; /* 1 if property found, 0 otherwise */
 }
 
 DUK_EXTERNAL duk_bool_t duk_has_prop_string(duk_hthread *thr, duk_idx_t obj_idx, const char *key) {
@@ -407,7 +407,7 @@ DUK_EXTERNAL duk_bool_t duk_has_prop_heapptr(duk_hthread *thr, duk_idx_t obj_idx
 	DUK_ASSERT_API_ENTRY(thr);
 
 	obj_idx = duk_require_normalize_index(thr, obj_idx);
-	(void) duk_push_heapptr(thr, ptr);  /* NULL -> 'undefined' */
+	(void) duk_push_heapptr(thr, ptr); /* NULL -> 'undefined' */
 	return duk_has_prop(thr, obj_idx);
 }
 
@@ -446,7 +446,7 @@ DUK_INTERNAL void duk_xdef_prop(duk_hthread *thr, duk_idx_t obj_idx, duk_small_u
 
 	duk_hobject_define_property_internal(thr, obj, key, desc_flags);
 
-	duk_pop(thr);  /* pop key */
+	duk_pop(thr); /* pop key */
 }
 
 DUK_INTERNAL void duk_xdef_prop_index(duk_hthread *thr, duk_idx_t obj_idx, duk_uarridx_t arr_idx, duk_small_uint_t desc_flags) {
@@ -479,12 +479,13 @@ DUK_INTERNAL void duk_xdef_prop_stridx(duk_hthread *thr, duk_idx_t obj_idx, duk_
 }
 
 DUK_INTERNAL void duk_xdef_prop_stridx_short_raw(duk_hthread *thr, duk_uint_t packed_args) {
-	duk_xdef_prop_stridx(thr, (duk_idx_t) (duk_int8_t) (packed_args >> 24),
-	                          (duk_small_uint_t) (packed_args >> 8) & 0xffffUL,
-	                          (duk_small_uint_t) (packed_args & 0xffL));
+	duk_xdef_prop_stridx(thr,
+	                     (duk_idx_t) (duk_int8_t) (packed_args >> 24),
+	                     (duk_small_uint_t) (packed_args >> 8) & 0xffffUL,
+	                     (duk_small_uint_t) (packed_args & 0xffL));
 }
 
-#if 0  /*unused*/
+#if 0 /*unused*/
 DUK_INTERNAL void duk_xdef_prop_stridx_builtin(duk_hthread *thr, duk_idx_t obj_idx, duk_small_uint_t stridx, duk_small_int_t builtin_idx, duk_small_uint_t desc_flags) {
 	duk_hobject *obj;
 	duk_hstring *key;
@@ -516,15 +517,15 @@ DUK_INTERNAL void duk_xdef_prop_stridx_thrower(duk_hthread *thr, duk_idx_t obj_i
 	duk_push_hstring_stridx(thr, stridx);
 	duk_push_hobject_bidx(thr, DUK_BIDX_TYPE_ERROR_THROWER);
 	duk_dup_top(thr);
-	duk_def_prop(thr, obj_idx, DUK_DEFPROP_HAVE_SETTER | DUK_DEFPROP_HAVE_GETTER | DUK_DEFPROP_FORCE);  /* attributes always 0 */
+	duk_def_prop(thr, obj_idx, DUK_DEFPROP_HAVE_SETTER | DUK_DEFPROP_HAVE_GETTER | DUK_DEFPROP_FORCE); /* attributes always 0 */
 }
 
 /* Object.getOwnPropertyDescriptor() equivalent C binding. */
 DUK_EXTERNAL void duk_get_prop_desc(duk_hthread *thr, duk_idx_t obj_idx, duk_uint_t flags) {
 	DUK_ASSERT_API_ENTRY(thr);
-	DUK_UNREF(flags);  /* no flags defined yet */
+	DUK_UNREF(flags); /* no flags defined yet */
 
-	duk_hobject_object_get_own_property_descriptor(thr, obj_idx);  /* [ ... key ] -> [ ... desc ] */
+	duk_hobject_object_get_own_property_descriptor(thr, obj_idx); /* [ ... key ] -> [ ... desc ] */
 }
 
 /* Object.defineProperty() equivalent C binding. */
@@ -554,9 +555,7 @@ DUK_EXTERNAL void duk_def_prop(duk_hthread *thr, duk_idx_t obj_idx, duk_uint_t f
 
 	idx_base = duk_get_top_index(thr);
 	if (flags & DUK_DEFPROP_HAVE_SETTER) {
-		duk_require_type_mask(thr, idx_base, DUK_TYPE_MASK_UNDEFINED |
-		                                     DUK_TYPE_MASK_OBJECT |
-		                                     DUK_TYPE_MASK_LIGHTFUNC);
+		duk_require_type_mask(thr, idx_base, DUK_TYPE_MASK_UNDEFINED | DUK_TYPE_MASK_OBJECT | DUK_TYPE_MASK_LIGHTFUNC);
 		set = duk_get_hobject_promote_lfunc(thr, idx_base);
 		if (set != NULL && !DUK_HOBJECT_IS_CALLABLE(set)) {
 			goto fail_not_callable;
@@ -566,9 +565,7 @@ DUK_EXTERNAL void duk_def_prop(duk_hthread *thr, duk_idx_t obj_idx, duk_uint_t f
 		set = NULL;
 	}
 	if (flags & DUK_DEFPROP_HAVE_GETTER) {
-		duk_require_type_mask(thr, idx_base, DUK_TYPE_MASK_UNDEFINED |
-		                                     DUK_TYPE_MASK_OBJECT |
-		                                     DUK_TYPE_MASK_LIGHTFUNC);
+		duk_require_type_mask(thr, idx_base, DUK_TYPE_MASK_UNDEFINED | DUK_TYPE_MASK_OBJECT | DUK_TYPE_MASK_LIGHTFUNC);
 		get = duk_get_hobject_promote_lfunc(thr, idx_base);
 		if (get != NULL && !DUK_HOBJECT_IS_CALLABLE(get)) {
 			goto fail_not_callable;
@@ -588,14 +585,7 @@ DUK_EXTERNAL void duk_def_prop(duk_hthread *thr, duk_idx_t obj_idx, duk_uint_t f
 
 	duk_require_valid_index(thr, idx_base);
 
-	duk_hobject_define_property_helper(thr,
-	                                   flags /*defprop_flags*/,
-	                                   obj,
-	                                   key,
-	                                   idx_value,
-	                                   get,
-	                                   set,
-	                                   1 /*throw_flag*/);
+	duk_hobject_define_property_helper(thr, flags /*defprop_flags*/, obj, key, idx_value, get, set, 1 /*throw_flag*/);
 
 	/* Clean up stack */
 
@@ -605,11 +595,11 @@ DUK_EXTERNAL void duk_def_prop(duk_hthread *thr, duk_idx_t obj_idx, duk_uint_t f
 
 	return;
 
- fail_invalid_desc:
+fail_invalid_desc:
 	DUK_ERROR_TYPE(thr, DUK_STR_INVALID_DESCRIPTOR);
 	DUK_WO_NORETURN(return;);
 
- fail_not_callable:
+fail_not_callable:
 	DUK_ERROR_TYPE(thr, DUK_STR_NOT_CALLABLE);
 	DUK_WO_NORETURN(return;);
 }
@@ -643,7 +633,7 @@ DUK_EXTERNAL void duk_enum(duk_hthread *thr, duk_idx_t obj_idx, duk_uint_t enum_
 
 	duk_dup(thr, obj_idx);
 	duk_require_hobject_promote_mask(thr, -1, DUK_TYPE_MASK_LIGHTFUNC | DUK_TYPE_MASK_BUFFER);
-	duk_hobject_enumerator_create(thr, enum_flags);   /* [target] -> [enum] */
+	duk_hobject_enumerator_create(thr, enum_flags); /* [target] -> [enum] */
 }
 
 DUK_EXTERNAL duk_bool_t duk_next(duk_hthread *thr, duk_idx_t enum_index, duk_bool_t get_value) {
@@ -704,8 +694,8 @@ DUK_INTERNAL void duk_seal_freeze_raw(duk_hthread *thr, duk_idx_t obj_idx, duk_b
 	}
 	return;
 
- fail_cannot_freeze:
-	DUK_ERROR_TYPE_INVALID_ARGS(thr);  /* XXX: proper error message */
+fail_cannot_freeze:
+	DUK_ERROR_TYPE_INVALID_ARGS(thr); /* XXX: proper error message */
 	DUK_WO_NORETURN(return;);
 }
 
@@ -750,8 +740,8 @@ DUK_EXTERNAL void duk_put_number_list(duk_hthread *thr, duk_idx_t obj_idx, const
 	if (ent != NULL) {
 		while (ent->key != NULL) {
 			tv = thr->valstack_top++;
-			DUK_ASSERT(DUK_TVAL_IS_UNDEFINED(tv));  /* value stack init policy */
-			DUK_TVAL_SET_NUMBER_CHKFAST_SLOW(tv, ent->value);  /* no need for decref/incref */
+			DUK_ASSERT(DUK_TVAL_IS_UNDEFINED(tv)); /* value stack init policy */
+			DUK_TVAL_SET_NUMBER_CHKFAST_SLOW(tv, ent->value); /* no need for decref/incref */
 			duk_put_prop_string(thr, obj_idx, ent->key);
 			ent++;
 		}
@@ -821,7 +811,6 @@ DUK_EXTERNAL duk_bool_t duk_get_global_heapptr(duk_hthread *thr, void *ptr) {
 	return ret;
 }
 
-
 DUK_EXTERNAL duk_bool_t duk_put_global_string(duk_hthread *thr, const char *key) {
 	duk_bool_t ret;
 
@@ -832,7 +821,7 @@ DUK_EXTERNAL duk_bool_t duk_put_global_string(duk_hthread *thr, const char *key)
 
 	duk_push_hobject(thr, thr->builtins[DUK_BIDX_GLOBAL]);
 	duk_insert(thr, -2);
-	ret = duk_put_prop_string(thr, -2, key);  /* [ ... global val ] -> [ ... global ] */
+	ret = duk_put_prop_string(thr, -2, key); /* [ ... global val ] -> [ ... global ] */
 	duk_pop(thr);
 	return ret;
 }
@@ -847,7 +836,7 @@ DUK_EXTERNAL duk_bool_t duk_put_global_lstring(duk_hthread *thr, const char *key
 
 	duk_push_hobject(thr, thr->builtins[DUK_BIDX_GLOBAL]);
 	duk_insert(thr, -2);
-	ret = duk_put_prop_lstring(thr, -2, key, key_len);  /* [ ... global val ] -> [ ... global ] */
+	ret = duk_put_prop_lstring(thr, -2, key, key_len); /* [ ... global val ] -> [ ... global ] */
 	duk_pop(thr);
 	return ret;
 }
@@ -864,7 +853,7 @@ DUK_EXTERNAL duk_bool_t duk_put_global_literal_raw(duk_hthread *thr, const char
 
 	duk_push_hobject(thr, thr->builtins[DUK_BIDX_GLOBAL]);
 	duk_insert(thr, -2);
-	ret = duk_put_prop_literal_raw(thr, -2, key, key_len);  /* [ ... global val ] -> [ ... global ] */
+	ret = duk_put_prop_literal_raw(thr, -2, key, key_len); /* [ ... global val ] -> [ ... global ] */
 	duk_pop(thr);
 	return ret;
 }
@@ -880,7 +869,7 @@ DUK_EXTERNAL duk_bool_t duk_put_global_heapptr(duk_hthread *thr, void *ptr) {
 
 	duk_push_hobject(thr, thr->builtins[DUK_BIDX_GLOBAL]);
 	duk_insert(thr, -2);
-	ret = duk_put_prop_heapptr(thr, -2, ptr);  /* [ ... global val ] -> [ ... global ] */
+	ret = duk_put_prop_heapptr(thr, -2, ptr); /* [ ... global val ] -> [ ... global ] */
 	duk_pop(thr);
 	return ret;
 }
@@ -932,14 +921,13 @@ DUK_EXTERNAL void duk_set_prototype(duk_hthread *thr, duk_idx_t idx) {
 
 	obj = duk_require_hobject(thr, idx);
 	DUK_ASSERT(obj != NULL);
-	duk_require_type_mask(thr, -1, DUK_TYPE_MASK_UNDEFINED |
-	                               DUK_TYPE_MASK_OBJECT);
+	duk_require_type_mask(thr, -1, DUK_TYPE_MASK_UNDEFINED | DUK_TYPE_MASK_OBJECT);
 	proto = duk_get_hobject(thr, -1);
 	/* proto can also be NULL here (allowed explicitly) */
 
 #if defined(DUK_USE_ROM_OBJECTS)
 	if (DUK_HEAPHDR_HAS_READONLY((duk_heaphdr *) obj)) {
-		DUK_ERROR_TYPE(thr, DUK_STR_NOT_CONFIGURABLE);  /* XXX: "read only object"? */
+		DUK_ERROR_TYPE(thr, DUK_STR_NOT_CONFIGURABLE); /* XXX: "read only object"? */
 		DUK_WO_NORETURN(return;);
 	}
 #endif
@@ -959,7 +947,7 @@ DUK_INTERNAL void duk_clear_prototype(duk_hthread *thr, duk_idx_t idx) {
 
 #if defined(DUK_USE_ROM_OBJECTS)
 	if (DUK_HEAPHDR_HAS_READONLY((duk_heaphdr *) obj)) {
-		DUK_ERROR_TYPE(thr, DUK_STR_NOT_CONFIGURABLE);  /* XXX: "read only object"? */
+		DUK_ERROR_TYPE(thr, DUK_STR_NOT_CONFIGURABLE); /* XXX: "read only object"? */
 		DUK_WO_NORETURN(return;);
 	}
 #endif
@@ -1006,7 +994,7 @@ DUK_EXTERNAL void duk_set_finalizer(duk_hthread *thr, duk_idx_t idx) {
 
 	DUK_ASSERT_API_ENTRY(thr);
 
-	h = duk_require_hobject(thr, idx);  /* Get before 'put' so that 'idx' is correct. */
+	h = duk_require_hobject(thr, idx); /* Get before 'put' so that 'idx' is correct. */
 	callable = duk_is_callable(thr, -1);
 
 	/* At present finalizer is stored as a hidden Symbol, with normal
@@ -1033,7 +1021,7 @@ DUK_EXTERNAL void duk_set_finalizer(duk_hthread *thr, duk_idx_t idx) {
 		DUK_HOBJECT_CLEAR_HAVE_FINALIZER(h);
 	}
 }
-#else  /* DUK_USE_FINALIZER_SUPPORT */
+#else /* DUK_USE_FINALIZER_SUPPORT */
 DUK_EXTERNAL void duk_get_finalizer(duk_hthread *thr, duk_idx_t idx) {
 	DUK_ASSERT_API_ENTRY(thr);
 	DUK_UNREF(idx);
@@ -1047,4 +1035,4 @@ DUK_EXTERNAL void duk_set_finalizer(duk_hthread *thr, duk_idx_t idx) {
 	DUK_ERROR_UNSUPPORTED(thr);
 	DUK_WO_NORETURN(return;);
 }
-#endif  /* DUK_USE_FINALIZER_SUPPORT */
+#endif /* DUK_USE_FINALIZER_SUPPORT */
