@@ -15,9 +15,8 @@ DUK_INTERNAL duk_ret_t duk_bi_error_constructor_shared(duk_hthread *thr) {
 	duk_small_int_t bidx_prototype = duk_get_current_magic(thr);
 
 	/* same for both error and each subclass like TypeError */
-	duk_uint_t flags_and_class = DUK_HOBJECT_FLAG_EXTENSIBLE |
-	                             DUK_HOBJECT_FLAG_FASTREFS |
-	                             DUK_HOBJECT_CLASS_AS_FLAGS(DUK_HOBJECT_CLASS_ERROR);
+	duk_uint_t flags_and_class =
+	    DUK_HOBJECT_FLAG_EXTENSIBLE | DUK_HOBJECT_FLAG_FASTREFS | DUK_HOBJECT_CLASS_AS_FLAGS(DUK_HOBJECT_CLASS_ERROR);
 
 	(void) duk_push_object_helper(thr, flags_and_class, bidx_prototype);
 
@@ -26,7 +25,7 @@ DUK_INTERNAL duk_ret_t duk_bi_error_constructor_shared(duk_hthread *thr) {
 	 */
 	if (!duk_is_undefined(thr, 0)) {
 		duk_to_string(thr, 0);
-		duk_dup_0(thr);  /* [ message error message ] */
+		duk_dup_0(thr); /* [ message error message ] */
 		duk_xdef_prop_stridx_short(thr, -2, DUK_STRIDX_MESSAGE, DUK_PROPDESC_FLAGS_WC);
 	}
 
@@ -85,7 +84,7 @@ DUK_INTERNAL duk_ret_t duk_bi_error_prototype_to_string(duk_hthread *thr) {
 		return 1;
 	}
 	duk_push_literal(thr, ": ");
-	duk_insert(thr, -2);  /* ... name ': ' message */
+	duk_insert(thr, -2); /* ... name ': ' message */
 	duk_concat(thr, 3);
 
 	return 1;
@@ -108,15 +107,15 @@ DUK_INTERNAL duk_ret_t duk_bi_error_prototype_to_string(duk_hthread *thr) {
  */
 
 /* constants arbitrary, chosen for small loads */
-#define DUK__OUTPUT_TYPE_TRACEBACK   (-1)
-#define DUK__OUTPUT_TYPE_FILENAME    0
-#define DUK__OUTPUT_TYPE_LINENUMBER  1
+#define DUK__OUTPUT_TYPE_TRACEBACK  (-1)
+#define DUK__OUTPUT_TYPE_FILENAME   0
+#define DUK__OUTPUT_TYPE_LINENUMBER 1
 
 DUK_LOCAL duk_ret_t duk__error_getter_helper(duk_hthread *thr, duk_small_int_t output_type) {
 	duk_idx_t idx_td;
-	duk_small_int_t i;  /* traceback depth fits into 16 bits */
-	duk_small_int_t t;  /* stack type fits into 16 bits */
-	duk_small_int_t count_func = 0;  /* traceback depth ensures fits into 16 bits */
+	duk_small_int_t i; /* traceback depth fits into 16 bits */
+	duk_small_int_t t; /* stack type fits into 16 bits */
+	duk_small_int_t count_func = 0; /* traceback depth ensures fits into 16 bits */
 	const char *str_tailcall = " tailcall";
 	const char *str_strict = " strict";
 	const char *str_construct = " construct";
@@ -124,7 +123,7 @@ DUK_LOCAL duk_ret_t duk__error_getter_helper(duk_hthread *thr, duk_small_int_t o
 	const char *str_directeval = " directeval";
 	const char *str_empty = "";
 
-	DUK_ASSERT_TOP(thr, 0);  /* fixed arg count */
+	DUK_ASSERT_TOP(thr, 0); /* fixed arg count */
 
 	duk_push_this(thr);
 	duk_xget_owndataprop_stridx_short(thr, -1, DUK_STRIDX_INT_TRACEDATA);
@@ -139,7 +138,7 @@ DUK_LOCAL duk_ret_t duk__error_getter_helper(duk_hthread *thr, duk_small_int_t o
 
 	if (duk_check_type(thr, idx_td, DUK_TYPE_OBJECT)) {
 		/* Current tracedata contains 2 entries per callstack entry. */
-		for (i = 0; ; i += 2) {
+		for (i = 0;; i += 2) {
 			duk_int_t pc;
 			duk_uint_t line;
 			duk_uint_t flags;
@@ -195,46 +194,53 @@ DUK_LOCAL duk_ret_t duk__error_getter_helper(duk_hthread *thr, duk_small_int_t o
 
 				/* XXX: Change 'anon' handling here too, to use empty string for anonymous functions? */
 				/* XXX: Could be improved by coercing to a readable duk_tval (especially string escaping) */
-				h_name = duk_get_hstring_notsymbol(thr, -2);  /* may be NULL */
+				h_name = duk_get_hstring_notsymbol(thr, -2); /* may be NULL */
 				funcname = (h_name == NULL || h_name == DUK_HTHREAD_STRING_EMPTY_STRING(thr)) ?
-				           "[anon]" : (const char *) DUK_HSTRING_GET_DATA(h_name);
+                                               "[anon]" :
+                                               (const char *) DUK_HSTRING_GET_DATA(h_name);
 				filename = duk_get_string_notsymbol(thr, -1);
 				filename = filename ? filename : "";
 				DUK_ASSERT(funcname != NULL);
 				DUK_ASSERT(filename != NULL);
 
-				h_func = duk_get_hobject(thr, -4);  /* NULL for lightfunc */
+				h_func = duk_get_hobject(thr, -4); /* NULL for lightfunc */
 
 				if (h_func == NULL) {
-					duk_push_sprintf(thr, "at %s light%s%s%s%s%s",
-					                 (const char *) funcname,
-					                 (const char *) ((flags & DUK_ACT_FLAG_STRICT) ? str_strict : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_TAILCALLED) ? str_tailcall : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_CONSTRUCT) ? str_construct : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_DIRECT_EVAL) ? str_directeval : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_PREVENT_YIELD) ? str_prevyield : str_empty));
+					duk_push_sprintf(
+					    thr,
+					    "at %s light%s%s%s%s%s",
+					    (const char *) funcname,
+					    (const char *) ((flags & DUK_ACT_FLAG_STRICT) ? str_strict : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_TAILCALLED) ? str_tailcall : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_CONSTRUCT) ? str_construct : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_DIRECT_EVAL) ? str_directeval : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_PREVENT_YIELD) ? str_prevyield : str_empty));
 				} else if (DUK_HOBJECT_HAS_NATFUNC(h_func)) {
-					duk_push_sprintf(thr, "at %s (%s) native%s%s%s%s%s",
-					                 (const char *) funcname,
-					                 (const char *) filename,
-					                 (const char *) ((flags & DUK_ACT_FLAG_STRICT) ? str_strict : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_TAILCALLED) ? str_tailcall : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_CONSTRUCT) ? str_construct : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_DIRECT_EVAL) ? str_directeval : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_PREVENT_YIELD) ? str_prevyield : str_empty));
+					duk_push_sprintf(
+					    thr,
+					    "at %s (%s) native%s%s%s%s%s",
+					    (const char *) funcname,
+					    (const char *) filename,
+					    (const char *) ((flags & DUK_ACT_FLAG_STRICT) ? str_strict : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_TAILCALLED) ? str_tailcall : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_CONSTRUCT) ? str_construct : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_DIRECT_EVAL) ? str_directeval : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_PREVENT_YIELD) ? str_prevyield : str_empty));
 				} else {
-					duk_push_sprintf(thr, "at %s (%s:%lu)%s%s%s%s%s",
-					                 (const char *) funcname,
-					                 (const char *) filename,
-					                 (unsigned long) line,
-					                 (const char *) ((flags & DUK_ACT_FLAG_STRICT) ? str_strict : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_TAILCALLED) ? str_tailcall : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_CONSTRUCT) ? str_construct : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_DIRECT_EVAL) ? str_directeval : str_empty),
-					                 (const char *) ((flags & DUK_ACT_FLAG_PREVENT_YIELD) ? str_prevyield : str_empty));
+					duk_push_sprintf(
+					    thr,
+					    "at %s (%s:%lu)%s%s%s%s%s",
+					    (const char *) funcname,
+					    (const char *) filename,
+					    (unsigned long) line,
+					    (const char *) ((flags & DUK_ACT_FLAG_STRICT) ? str_strict : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_TAILCALLED) ? str_tailcall : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_CONSTRUCT) ? str_construct : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_DIRECT_EVAL) ? str_directeval : str_empty),
+					    (const char *) ((flags & DUK_ACT_FLAG_PREVENT_YIELD) ? str_prevyield : str_empty));
 				}
-				duk_replace(thr, -5);   /* [ ... v1 v2 name filename str ] -> [ ... str v2 name filename ] */
-				duk_pop_3(thr);         /* -> [ ... str ] */
+				duk_replace(thr, -5); /* [ ... v1 v2 name filename str ] -> [ ... str v2 name filename ] */
+				duk_pop_3(thr); /* -> [ ... str ] */
 			} else if (t == DUK_TYPE_STRING) {
 				const char *str_file;
 
@@ -265,10 +271,12 @@ DUK_LOCAL duk_ret_t duk__error_getter_helper(duk_hthread *thr, duk_small_int_t o
 				 * safety issues.
 				 */
 				str_file = (const char *) duk_get_string(thr, -2);
-				duk_push_sprintf(thr, "at [anon] (%s:%ld) internal",
-				                 (const char *) (str_file ? str_file : "null"), (long) pc);
-				duk_replace(thr, -3);  /* [ ... v1 v2 str ] -> [ ... str v2 ] */
-				duk_pop(thr);          /* -> [ ... str ] */
+				duk_push_sprintf(thr,
+				                 "at [anon] (%s:%ld) internal",
+				                 (const char *) (str_file ? str_file : "null"),
+				                 (long) pc);
+				duk_replace(thr, -3); /* [ ... v1 v2 str ] -> [ ... str v2 ] */
+				duk_pop(thr); /* -> [ ... str ] */
 			} else {
 				/* unknown, ignore */
 				duk_pop_2(thr);
@@ -315,7 +323,7 @@ DUK_INTERNAL duk_ret_t duk_bi_error_prototype_linenumber_getter(duk_hthread *thr
 	return duk__error_getter_helper(thr, DUK__OUTPUT_TYPE_LINENUMBER);
 }
 
-#else  /* DUK_USE_TRACEBACKS */
+#else /* DUK_USE_TRACEBACKS */
 
 /*
  *  Traceback handling when tracebacks disabled.
@@ -346,7 +354,7 @@ DUK_INTERNAL duk_ret_t duk_bi_error_prototype_linenumber_getter(duk_hthread *thr
 	return 0;
 }
 
-#endif  /* DUK_USE_TRACEBACKS */
+#endif /* DUK_USE_TRACEBACKS */
 
 DUK_LOCAL duk_ret_t duk__error_setter_helper(duk_hthread *thr, duk_small_uint_t stridx_key) {
 	/* Attempt to write 'stack', 'fileName', 'lineNumber' works as if
@@ -356,7 +364,7 @@ DUK_LOCAL duk_ret_t duk__error_setter_helper(duk_hthread *thr, duk_small_uint_t
 	 * See https://github.com/svaarala/duktape/issues/387.
 	 */
 
-	DUK_ASSERT_TOP(thr, 1);  /* fixed arg count: value */
+	DUK_ASSERT_TOP(thr, 1); /* fixed arg count: value */
 
 	duk_push_this(thr);
 	duk_push_hstring_stridx(thr, stridx_key);
@@ -364,13 +372,13 @@ DUK_LOCAL duk_ret_t duk__error_setter_helper(duk_hthread *thr, duk_small_uint_t
 
 	/* [ ... obj key value ] */
 
-	DUK_DD(DUK_DDPRINT("error setter: %!T %!T %!T",
-	                   duk_get_tval(thr, -3), duk_get_tval(thr, -2), duk_get_tval(thr, -1)));
+	DUK_DD(DUK_DDPRINT("error setter: %!T %!T %!T", duk_get_tval(thr, -3), duk_get_tval(thr, -2), duk_get_tval(thr, -1)));
 
-	duk_def_prop(thr, -3, DUK_DEFPROP_HAVE_VALUE |
-	                      DUK_DEFPROP_HAVE_WRITABLE | DUK_DEFPROP_WRITABLE |
-	                      DUK_DEFPROP_HAVE_ENUMERABLE | /*not enumerable*/
-	                      DUK_DEFPROP_HAVE_CONFIGURABLE | DUK_DEFPROP_CONFIGURABLE);
+	duk_def_prop(thr,
+	             -3,
+	             DUK_DEFPROP_HAVE_VALUE | DUK_DEFPROP_HAVE_WRITABLE | DUK_DEFPROP_WRITABLE |
+	                 DUK_DEFPROP_HAVE_ENUMERABLE | /*not enumerable*/
+	                 DUK_DEFPROP_HAVE_CONFIGURABLE | DUK_DEFPROP_CONFIGURABLE);
 	return 0;
 }
 
