@@ -10,15 +10,17 @@
  */
 #define DUK_HBOUNDFUNC_MAX_ARGS 0x20000000UL
 
-#define DUK_ASSERT_HBOUNDFUNC_VALID(h) do { \
-		DUK_ASSERT((h) != NULL); \
-		DUK_ASSERT(DUK_HOBJECT_IS_BOUNDFUNC((duk_hobject *) (h))); \
-		DUK_ASSERT(DUK_TVAL_IS_LIGHTFUNC(&(h)->target) || \
-		           (DUK_TVAL_IS_OBJECT(&(h)->target) && \
-		            DUK_HOBJECT_IS_CALLABLE(DUK_TVAL_GET_OBJECT(&(h)->target)))); \
-		DUK_ASSERT(!DUK_TVAL_IS_UNUSED(&(h)->this_binding)); \
-		DUK_ASSERT((h)->nargs == 0 || (h)->args != NULL); \
+#if defined(DUK_USE_ASSERTIONS)
+DUK_INTERNAL_DECL void duk_hboundfunc_assert_valid(duk_hboundfunc *h);
+#define DUK_HBOUNDFUNC_ASSERT_VALID(h) \
+	do { \
+		duk_hboundfunc_assert_valid((h)); \
 	} while (0)
+#else
+#define DUK_HBOUNDFUNC_ASSERT_VALID(h) \
+	do { \
+	} while (0)
+#endif
 
 struct duk_hboundfunc {
 	/* Shared object part. */
@@ -33,8 +35,8 @@ struct duk_hboundfunc {
 	duk_tval this_binding;
 
 	/* Arguments to prepend. */
-	duk_tval *args;  /* Separate allocation. */
+	duk_tval *args; /* Separate allocation. */
 	duk_idx_t nargs;
 };
 
-#endif  /* DUK_HBOUNDFUNC_H_INCLUDED */
+#endif /* DUK_HBOUNDFUNC_H_INCLUDED */
