@@ -10,21 +10,21 @@
  *  Encoding constants, must match genbuiltins.py
  */
 
-#define DUK__PROP_FLAGS_BITS             3
-#define DUK__LENGTH_PROP_BITS            3
-#define DUK__NARGS_BITS                  3
-#define DUK__PROP_TYPE_BITS              3
+#define DUK__PROP_FLAGS_BITS  3
+#define DUK__LENGTH_PROP_BITS 3
+#define DUK__NARGS_BITS       3
+#define DUK__PROP_TYPE_BITS   3
 
-#define DUK__NARGS_VARARGS_MARKER        0x07
+#define DUK__NARGS_VARARGS_MARKER 0x07
 
-#define DUK__PROP_TYPE_DOUBLE            0
-#define DUK__PROP_TYPE_STRING            1
-#define DUK__PROP_TYPE_STRIDX            2
-#define DUK__PROP_TYPE_BUILTIN           3
-#define DUK__PROP_TYPE_UNDEFINED         4
-#define DUK__PROP_TYPE_BOOLEAN_TRUE      5
-#define DUK__PROP_TYPE_BOOLEAN_FALSE     6
-#define DUK__PROP_TYPE_ACCESSOR          7
+#define DUK__PROP_TYPE_DOUBLE        0
+#define DUK__PROP_TYPE_STRING        1
+#define DUK__PROP_TYPE_STRIDX        2
+#define DUK__PROP_TYPE_BUILTIN       3
+#define DUK__PROP_TYPE_UNDEFINED     4
+#define DUK__PROP_TYPE_BOOLEAN_TRUE  5
+#define DUK__PROP_TYPE_BOOLEAN_FALSE 6
+#define DUK__PROP_TYPE_ACCESSOR      7
 
 /*
  *  Create built-in objects by parsing an init bitstream generated
@@ -47,9 +47,8 @@ DUK_LOCAL void duk__duplicate_ram_global_object(duk_hthread *thr) {
 #if defined(DUK_USE_ROM_GLOBAL_INHERIT)
 	/* Inherit from ROM-based global object: less RAM usage, less transparent. */
 	h_global = duk_push_object_helper(thr,
-	                                  DUK_HOBJECT_FLAG_EXTENSIBLE |
-	                                  DUK_HOBJECT_FLAG_FASTREFS |
-	                                  DUK_HOBJECT_CLASS_AS_FLAGS(DUK_HOBJECT_CLASS_GLOBAL),
+	                                  DUK_HOBJECT_FLAG_EXTENSIBLE | DUK_HOBJECT_FLAG_FASTREFS |
+	                                      DUK_HOBJECT_CLASS_AS_FLAGS(DUK_HOBJECT_CLASS_GLOBAL),
 	                                  DUK_BIDX_GLOBAL);
 	DUK_ASSERT(h_global != NULL);
 #elif defined(DUK_USE_ROM_GLOBAL_CLONE)
@@ -58,9 +57,8 @@ DUK_LOCAL void duk__duplicate_ram_global_object(duk_hthread *thr) {
 	 * model but more compliant.
 	 */
 	h_global = duk_push_object_helper(thr,
-	                                  DUK_HOBJECT_FLAG_EXTENSIBLE |
-	                                  DUK_HOBJECT_FLAG_FASTREFS |
-	                                  DUK_HOBJECT_CLASS_AS_FLAGS(DUK_HOBJECT_CLASS_GLOBAL),
+	                                  DUK_HOBJECT_FLAG_EXTENSIBLE | DUK_HOBJECT_FLAG_FASTREFS |
+	                                      DUK_HOBJECT_CLASS_AS_FLAGS(DUK_HOBJECT_CLASS_GLOBAL),
 	                                  DUK_BIDX_OBJECT_PROTOTYPE);
 	DUK_ASSERT(h_global != NULL);
 	h_oldglobal = thr->builtins[DUK_BIDX_GLOBAL];
@@ -94,7 +92,8 @@ DUK_LOCAL void duk__duplicate_ram_global_object(duk_hthread *thr) {
 
 	duk_hobject_compact_props(thr, h_global);
 	DUK_ASSERT(thr->builtins[DUK_BIDX_GLOBAL] != NULL);
-	DUK_ASSERT(!DUK_HEAPHDR_NEEDS_REFCOUNT_UPDATE((duk_heaphdr *) thr->builtins[DUK_BIDX_GLOBAL]));  /* no need to decref: ROM object */
+	DUK_ASSERT(
+	    !DUK_HEAPHDR_NEEDS_REFCOUNT_UPDATE((duk_heaphdr *) thr->builtins[DUK_BIDX_GLOBAL])); /* no need to decref: ROM object */
 	thr->builtins[DUK_BIDX_GLOBAL] = h_global;
 	DUK_HOBJECT_INCREF(thr, h_global);
 	DUK_D(DUK_DPRINT("duplicated global object: %!O", h_global));
@@ -103,9 +102,9 @@ DUK_LOCAL void duk__duplicate_ram_global_object(duk_hthread *thr) {
 	 * needed so that the global scope points to the newly created RAM-based
 	 * global object.
 	 */
-	h_objenv = (duk_hobject *) duk_hobjenv_alloc(thr,
-	                                             DUK_HOBJECT_FLAG_EXTENSIBLE |
-	                                             DUK_HOBJECT_CLASS_AS_FLAGS(DUK_HOBJECT_CLASS_OBJENV));
+	h_objenv =
+	    (duk_hobject *) duk_hobjenv_alloc(thr,
+	                                      DUK_HOBJECT_FLAG_EXTENSIBLE | DUK_HOBJECT_CLASS_AS_FLAGS(DUK_HOBJECT_CLASS_OBJENV));
 	DUK_ASSERT(h_objenv != NULL);
 	DUK_ASSERT(DUK_HOBJECT_GET_PROTOTYPE(thr->heap, h_objenv) == NULL);
 	duk_push_hobject(thr, h_objenv);
@@ -116,16 +115,17 @@ DUK_LOCAL void duk__duplicate_ram_global_object(duk_hthread *thr) {
 	DUK_ASSERT(((duk_hobjenv *) h_objenv)->has_this == 0);
 
 	DUK_ASSERT(thr->builtins[DUK_BIDX_GLOBAL_ENV] != NULL);
-	DUK_ASSERT(!DUK_HEAPHDR_NEEDS_REFCOUNT_UPDATE((duk_heaphdr *) thr->builtins[DUK_BIDX_GLOBAL_ENV]));  /* no need to decref: ROM object */
+	DUK_ASSERT(!DUK_HEAPHDR_NEEDS_REFCOUNT_UPDATE(
+	    (duk_heaphdr *) thr->builtins[DUK_BIDX_GLOBAL_ENV])); /* no need to decref: ROM object */
 	thr->builtins[DUK_BIDX_GLOBAL_ENV] = h_objenv;
 	DUK_HOBJECT_INCREF(thr, h_objenv);
 	DUK_D(DUK_DPRINT("duplicated global env: %!O", h_objenv));
 
-	DUK_ASSERT_HOBJENV_VALID((duk_hobjenv *) h_objenv);
+	DUK_HOBJENV_ASSERT_VALID((duk_hobjenv *) h_objenv);
 
-	duk_pop_2(thr);  /* Pop global object and global env. */
+	duk_pop_2(thr); /* Pop global object and global env. */
 }
-#endif  /* DUK_USE_ROM_GLOBAL_CLONE || DUK_USE_ROM_GLOBAL_INHERIT */
+#endif /* DUK_USE_ROM_GLOBAL_CLONE || DUK_USE_ROM_GLOBAL_INHERIT */
 
 DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 	/* Setup builtins from ROM objects.  All heaps/threads will share
@@ -149,12 +149,12 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 	duk__duplicate_ram_global_object(thr);
 #endif
 }
-#else  /* DUK_USE_ROM_OBJECTS */
+#else /* DUK_USE_ROM_OBJECTS */
 DUK_LOCAL void duk__push_stridx(duk_hthread *thr, duk_bitdecoder_ctx *bd) {
 	duk_small_uint_t n;
 
 	n = (duk_small_uint_t) duk_bd_decode_varuint(bd);
-	DUK_ASSERT_DISABLE(n >= 0);  /* unsigned */
+	DUK_ASSERT_DISABLE(n >= 0); /* unsigned */
 	DUK_ASSERT(n < DUK_HEAP_NUM_STRINGS);
 	duk_push_hstring_stridx(thr, n);
 }
@@ -191,16 +191,18 @@ DUK_LOCAL void duk__push_double(duk_hthread *thr, duk_bitdecoder_ctx *bd) {
 		du.uc[i] = (duk_uint8_t) duk_bd_decode(bd, 8);
 	}
 
-	duk_push_number(thr, du.d);  /* push operation normalizes NaNs */
+	duk_push_number(thr, du.d); /* push operation normalizes NaNs */
 }
 
 DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 	duk_bitdecoder_ctx bd_ctx;
-	duk_bitdecoder_ctx *bd = &bd_ctx;  /* convenience */
+	duk_bitdecoder_ctx *bd = &bd_ctx; /* convenience */
 	duk_hobject *h;
 	duk_small_uint_t i, j;
 
-	DUK_D(DUK_DPRINT("INITBUILTINS BEGIN: DUK_NUM_BUILTINS=%d, DUK_NUM_BUILTINS_ALL=%d", (int) DUK_NUM_BUILTINS, (int) DUK_NUM_ALL_BUILTINS));
+	DUK_D(DUK_DPRINT("INITBUILTINS BEGIN: DUK_NUM_BUILTINS=%d, DUK_NUM_BUILTINS_ALL=%d",
+	                 (int) DUK_NUM_BUILTINS,
+	                 (int) DUK_NUM_ALL_BUILTINS));
 
 	duk_memzero(&bd_ctx, sizeof(bd_ctx));
 	bd->data = (const duk_uint8_t *) duk_builtins_data;
@@ -227,14 +229,14 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 	DUK_ASSERT_TOP(thr, 0);
 	for (i = 0; i < DUK_NUM_ALL_BUILTINS; i++) {
 		duk_small_uint_t class_num;
-		duk_small_int_t len = -1;  /* must be signed */
+		duk_small_int_t len = -1; /* must be signed */
 
 		class_num = (duk_small_uint_t) duk_bd_decode_varuint(bd);
 		len = (duk_small_int_t) duk_bd_decode_flagged_signed(bd, DUK__LENGTH_PROP_BITS, (duk_int32_t) -1 /*def_value*/);
 
 		if (class_num == DUK_HOBJECT_CLASS_FUNCTION) {
 			duk_small_uint_t natidx;
-			duk_small_int_t c_nargs;  /* must hold DUK_VARARGS */
+			duk_small_int_t c_nargs; /* must hold DUK_VARARGS */
 			duk_c_function c_func;
 			duk_int16_t magic;
 
@@ -265,12 +267,9 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 
 			duk__push_stridx_or_string(thr, bd);
 #if defined(DUK_USE_FUNC_NAME_PROPERTY)
-			duk_xdef_prop_stridx_short(thr,
-			                           -2,
-			                           DUK_STRIDX_NAME,
-			                           DUK_PROPDESC_FLAGS_C);
+			duk_xdef_prop_stridx_short(thr, -2, DUK_STRIDX_NAME, DUK_PROPDESC_FLAGS_C);
 #else
-			duk_pop(thr);  /* Not very ideal but good enough for now. */
+			duk_pop(thr); /* Not very ideal but good enough for now. */
 #endif
 
 			/* Almost all global level Function objects are constructable
@@ -296,8 +295,7 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 			DUK_ASSERT(DUK_BIDX_GLOBAL_ENV > DUK_BIDX_GLOBAL);
 
 			env = duk_hobjenv_alloc(thr,
-	                                        DUK_HOBJECT_FLAG_EXTENSIBLE |
-	                                        DUK_HOBJECT_CLASS_AS_FLAGS(DUK_HOBJECT_CLASS_OBJENV));
+			                        DUK_HOBJECT_FLAG_EXTENSIBLE | DUK_HOBJECT_CLASS_AS_FLAGS(DUK_HOBJECT_CLASS_OBJENV));
 			DUK_ASSERT(env->target == NULL);
 			duk_push_hobject(thr, (duk_hobject *) env);
 
@@ -307,15 +305,13 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 			DUK_HOBJECT_INCREF(thr, global);
 			DUK_ASSERT(env->has_this == 0);
 
-			DUK_ASSERT_HOBJENV_VALID(env);
+			DUK_HOBJENV_ASSERT_VALID(env);
 		} else {
 			DUK_ASSERT(class_num != DUK_HOBJECT_CLASS_DECENV);
 
 			(void) duk_push_object_helper(thr,
-			                              DUK_HOBJECT_FLAG_FASTREFS |
-			                              DUK_HOBJECT_FLAG_EXTENSIBLE,
-			                              -1);  /* no prototype or class yet */
-
+			                              DUK_HOBJECT_FLAG_FASTREFS | DUK_HOBJECT_FLAG_EXTENSIBLE,
+			                              -1); /* no prototype or class yet */
 		}
 
 		h = duk_known_hobject(thr, -1);
@@ -337,18 +333,15 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 			 * not encoded explicitly in init data.
 			 */
 
-			DUK_ASSERT(class_num != DUK_HOBJECT_CLASS_ARRAY);  /* .length is virtual */
+			DUK_ASSERT(class_num != DUK_HOBJECT_CLASS_ARRAY); /* .length is virtual */
 			duk_push_int(thr, len);
-			duk_xdef_prop_stridx_short(thr,
-			                           -2,
-			                           DUK_STRIDX_LENGTH,
-			                           DUK_PROPDESC_FLAGS_C);
+			duk_xdef_prop_stridx_short(thr, -2, DUK_STRIDX_LENGTH, DUK_PROPDESC_FLAGS_C);
 		}
 
 		/* enable exotic behaviors last */
 
 		if (class_num == DUK_HOBJECT_CLASS_ARRAY) {
-			DUK_ASSERT(DUK_HOBJECT_HAS_EXOTIC_ARRAY(h));  /* set by duk_push_array() */
+			DUK_ASSERT(DUK_HOBJECT_HAS_EXOTIC_ARRAY(h)); /* set by duk_push_array() */
 		}
 		if (class_num == DUK_HOBJECT_CLASS_STRING) {
 			DUK_HOBJECT_SET_EXOTIC_STRINGOBJ(h);
@@ -362,9 +355,10 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 		DUK_ASSERT(!DUK_HOBJECT_HAS_COMPFUNC(h));
 		/* DUK_HOBJECT_FLAG_NATFUNC varies */
 		DUK_ASSERT(!DUK_HOBJECT_IS_THREAD(h));
+		DUK_ASSERT(!DUK_HOBJECT_IS_PROXY(h));
 		DUK_ASSERT(!DUK_HOBJECT_HAS_ARRAY_PART(h) || class_num == DUK_HOBJECT_CLASS_ARRAY);
 		/* DUK_HOBJECT_FLAG_STRICT varies */
-		DUK_ASSERT(!DUK_HOBJECT_HAS_NATFUNC(h) ||  /* all native functions have NEWENV */
+		DUK_ASSERT(!DUK_HOBJECT_HAS_NATFUNC(h) || /* all native functions have NEWENV */
 		           DUK_HOBJECT_HAS_NEWENV(h));
 		DUK_ASSERT(!DUK_HOBJECT_HAS_NAMEBINDING(h));
 		DUK_ASSERT(!DUK_HOBJECT_HAS_CREATEARGS(h));
@@ -447,11 +441,9 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 			defprop_flags = (duk_small_uint_t) duk_bd_decode_flagged(bd,
 			                                                         DUK__PROP_FLAGS_BITS,
 			                                                         (duk_uint32_t) DUK_PROPDESC_FLAGS_WC);
-			defprop_flags |= DUK_DEFPROP_FORCE |
-			                 DUK_DEFPROP_HAVE_VALUE |
-			                 DUK_DEFPROP_HAVE_WRITABLE |
+			defprop_flags |= DUK_DEFPROP_FORCE | DUK_DEFPROP_HAVE_VALUE | DUK_DEFPROP_HAVE_WRITABLE |
 			                 DUK_DEFPROP_HAVE_ENUMERABLE |
-			                 DUK_DEFPROP_HAVE_CONFIGURABLE;  /* Defaults for data properties. */
+			                 DUK_DEFPROP_HAVE_CONFIGURABLE; /* Defaults for data properties. */
 
 			/* The writable, enumerable, configurable flags in prop_flags
 			 * match both duk_def_prop() and internal property flags.
@@ -463,7 +455,11 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 			t = (duk_small_uint_t) duk_bd_decode(bd, DUK__PROP_TYPE_BITS);
 
 			DUK_DDD(DUK_DDDPRINT("built-in %ld, normal-valued property %ld, key %!T, flags 0x%02lx, type %ld",
-			                     (long) i, (long) j, duk_get_tval(thr, -1), (unsigned long) defprop_flags, (long) t));
+			                     (long) i,
+			                     (long) j,
+			                     duk_get_tval(thr, -1),
+			                     (unsigned long) defprop_flags,
+			                     (long) t));
 
 			switch (t) {
 			case DUK__PROP_TYPE_DOUBLE: {
@@ -504,24 +500,29 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 				duk_c_function c_func_getter;
 				duk_c_function c_func_setter;
 
-				DUK_DDD(DUK_DDDPRINT("built-in accessor property: objidx=%ld, key=%!T, getteridx=%ld, setteridx=%ld, flags=0x%04lx",
-				                     (long) i, duk_get_tval(thr, -1), (long) natidx_getter, (long) natidx_setter, (unsigned long) defprop_flags));
+				DUK_DDD(DUK_DDDPRINT(
+				    "built-in accessor property: objidx=%ld, key=%!T, getteridx=%ld, setteridx=%ld, flags=0x%04lx",
+				    (long) i,
+				    duk_get_tval(thr, -1),
+				    (long) natidx_getter,
+				    (long) natidx_setter,
+				    (unsigned long) defprop_flags));
 
 				c_func_getter = duk_bi_native_functions[natidx_getter];
 				if (c_func_getter != NULL) {
-					duk_push_c_function_builtin_noconstruct(thr, c_func_getter, 0);  /* always 0 args */
+					duk_push_c_function_builtin_noconstruct(thr, c_func_getter, 0); /* always 0 args */
 					duk_set_magic(thr, -1, (duk_int_t) accessor_magic);
 					defprop_flags |= DUK_DEFPROP_HAVE_GETTER;
 				}
 				c_func_setter = duk_bi_native_functions[natidx_setter];
 				if (c_func_setter != NULL) {
-					duk_push_c_function_builtin_noconstruct(thr, c_func_setter, 1);  /* always 1 arg */
+					duk_push_c_function_builtin_noconstruct(thr, c_func_setter, 1); /* always 1 arg */
 					duk_set_magic(thr, -1, (duk_int_t) accessor_magic);
 					defprop_flags |= DUK_DEFPROP_HAVE_SETTER;
 				}
 
 				/* Writable flag doesn't make sense for an accessor. */
-				DUK_ASSERT((defprop_flags & DUK_PROPDESC_FLAG_WRITABLE) == 0);  /* genbuiltins.py ensures */
+				DUK_ASSERT((defprop_flags & DUK_PROPDESC_FLAG_WRITABLE) == 0); /* genbuiltins.py ensures */
 
 				defprop_flags &= ~(DUK_DEFPROP_HAVE_VALUE | DUK_DEFPROP_HAVE_WRITABLE);
 				defprop_flags |= DUK_DEFPROP_HAVE_ENUMERABLE | DUK_DEFPROP_HAVE_CONFIGURABLE;
@@ -543,7 +544,7 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 		for (j = 0; j < num; j++) {
 			duk_hstring *h_key;
 			duk_small_uint_t natidx;
-			duk_int_t c_nargs;  /* must hold DUK_VARARGS */
+			duk_int_t c_nargs; /* must hold DUK_VARARGS */
 			duk_small_uint_t c_length;
 			duk_int16_t magic;
 			duk_c_function c_func;
@@ -566,51 +567,66 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 
 			c_func = duk_bi_native_functions[natidx];
 
-			DUK_DDD(DUK_DDDPRINT("built-in %ld, function-valued property %ld, key %!O, natidx %ld, length %ld, nargs %ld",
-			                     (long) i, (long) j, (duk_heaphdr *) h_key, (long) natidx, (long) c_length,
-			                     (c_nargs == DUK_VARARGS ? (long) -1 : (long) c_nargs)));
+			DUK_DDD(
+			    DUK_DDDPRINT("built-in %ld, function-valued property %ld, key %!O, natidx %ld, length %ld, nargs %ld",
+			                 (long) i,
+			                 (long) j,
+			                 (duk_heaphdr *) h_key,
+			                 (long) natidx,
+			                 (long) c_length,
+			                 (c_nargs == DUK_VARARGS ? (long) -1 : (long) c_nargs)));
 
 			/* Cast converts magic to 16-bit signed value */
 			magic = (duk_int16_t) duk_bd_decode_varuint(bd);
 
 #if defined(DUK_USE_LIGHTFUNC_BUILTINS)
 			lightfunc_eligible =
-				((c_nargs >= DUK_LFUNC_NARGS_MIN && c_nargs <= DUK_LFUNC_NARGS_MAX) || (c_nargs == DUK_VARARGS)) &&
-				(c_length <= DUK_LFUNC_LENGTH_MAX) &&
-				(magic >= DUK_LFUNC_MAGIC_MIN && magic <= DUK_LFUNC_MAGIC_MAX);
+			    ((c_nargs >= DUK_LFUNC_NARGS_MIN && c_nargs <= DUK_LFUNC_NARGS_MAX) || (c_nargs == DUK_VARARGS)) &&
+			    (c_length <= DUK_LFUNC_LENGTH_MAX) && (magic >= DUK_LFUNC_MAGIC_MIN && magic <= DUK_LFUNC_MAGIC_MAX);
 
 			/* These functions have trouble working as lightfuncs.
 			 * Some of them have specific asserts and some may have
-		         * additional properties (e.g. 'require.id' may be written).
+			 * additional properties (e.g. 'require.id' may be written).
 			 */
 			if (c_func == duk_bi_global_object_eval) {
 				lightfunc_eligible = 0;
 			}
 #if defined(DUK_USE_COROUTINE_SUPPORT)
-			if (c_func == duk_bi_thread_yield ||
-			    c_func == duk_bi_thread_resume) {
+			if (c_func == duk_bi_thread_yield || c_func == duk_bi_thread_resume) {
 				lightfunc_eligible = 0;
 			}
 #endif
-			if (c_func == duk_bi_function_prototype_call ||
-			    c_func == duk_bi_function_prototype_apply ||
-			    c_func == duk_bi_reflect_apply ||
-			    c_func == duk_bi_reflect_construct) {
+			if (c_func == duk_bi_function_prototype_call || c_func == duk_bi_function_prototype_apply ||
+			    c_func == duk_bi_reflect_apply || c_func == duk_bi_reflect_construct) {
 				lightfunc_eligible = 0;
 			}
 
 			if (lightfunc_eligible) {
 				duk_tval tv_lfunc;
-				duk_small_uint_t lf_nargs = (duk_small_uint_t) (c_nargs == DUK_VARARGS ? DUK_LFUNC_NARGS_VARARGS : c_nargs);
+				duk_small_uint_t lf_nargs =
+				    (duk_small_uint_t) (c_nargs == DUK_VARARGS ? DUK_LFUNC_NARGS_VARARGS : c_nargs);
 				duk_small_uint_t lf_flags = DUK_LFUNC_FLAGS_PACK(magic, c_length, lf_nargs);
 				DUK_TVAL_SET_LIGHTFUNC(&tv_lfunc, c_func, lf_flags);
 				duk_push_tval(thr, &tv_lfunc);
-				DUK_D(DUK_DPRINT("built-in function eligible as light function: i=%d, j=%d c_length=%ld, c_nargs=%ld, magic=%ld -> %!iT", (int) i, (int) j, (long) c_length, (long) c_nargs, (long) magic, duk_get_tval(thr, -1)));
+				DUK_D(DUK_DPRINT("built-in function eligible as light function: i=%d, j=%d c_length=%ld, "
+				                 "c_nargs=%ld, magic=%ld -> %!iT",
+				                 (int) i,
+				                 (int) j,
+				                 (long) c_length,
+				                 (long) c_nargs,
+				                 (long) magic,
+				                 duk_get_tval(thr, -1)));
 				goto lightfunc_skip;
 			}
 
-			DUK_D(DUK_DPRINT("built-in function NOT ELIGIBLE as light function: i=%d, j=%d c_length=%ld, c_nargs=%ld, magic=%ld", (int) i, (int) j, (long) c_length, (long) c_nargs, (long) magic));
-#endif  /* DUK_USE_LIGHTFUNC_BUILTINS */
+			DUK_D(DUK_DPRINT(
+			    "built-in function NOT ELIGIBLE as light function: i=%d, j=%d c_length=%ld, c_nargs=%ld, magic=%ld",
+			    (int) i,
+			    (int) j,
+			    (long) c_length,
+			    (long) c_nargs,
+			    (long) magic));
+#endif /* DUK_USE_LIGHTFUNC_BUILTINS */
 
 			/* [ (builtin objects) name ] */
 
@@ -621,10 +637,8 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 			/* XXX: add into init data? */
 
 			/* Special call handling, not described in init data. */
-			if (c_func == duk_bi_global_object_eval ||
-			    c_func == duk_bi_function_prototype_call ||
-			    c_func == duk_bi_function_prototype_apply ||
-			    c_func == duk_bi_reflect_apply ||
+			if (c_func == duk_bi_global_object_eval || c_func == duk_bi_function_prototype_call ||
+			    c_func == duk_bi_function_prototype_apply || c_func == duk_bi_reflect_apply ||
 			    c_func == duk_bi_reflect_construct) {
 				DUK_HOBJECT_SET_SPECIAL_CALL((duk_hobject *) h_func);
 			}
@@ -658,7 +672,9 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 			/* XXX: other properties of function instances; 'arguments', 'caller'. */
 
 			DUK_DD(DUK_DDPRINT("built-in object %ld, function property %ld -> %!T",
-			                   (long) i, (long) j, (duk_tval *) duk_get_tval(thr, -1)));
+			                   (long) i,
+			                   (long) j,
+			                   (duk_tval *) duk_get_tval(thr, -1)));
 
 			/* [ (builtin objects) name func ] */
 
@@ -668,17 +684,14 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 			 */
 
 #if defined(DUK_USE_LIGHTFUNC_BUILTINS)
-		 lightfunc_skip:
+		lightfunc_skip:
 #endif
 
 			defprop_flags = (duk_small_uint_t) duk_bd_decode_flagged(bd,
 			                                                         DUK__PROP_FLAGS_BITS,
 			                                                         (duk_uint32_t) DUK_PROPDESC_FLAGS_WC);
-			defprop_flags |= DUK_DEFPROP_FORCE |
-			                 DUK_DEFPROP_HAVE_VALUE |
-			                 DUK_DEFPROP_HAVE_WRITABLE |
-			                 DUK_DEFPROP_HAVE_ENUMERABLE |
-			                 DUK_DEFPROP_HAVE_CONFIGURABLE;
+			defprop_flags |= DUK_DEFPROP_FORCE | DUK_DEFPROP_HAVE_VALUE | DUK_DEFPROP_HAVE_WRITABLE |
+			                 DUK_DEFPROP_HAVE_ENUMERABLE | DUK_DEFPROP_HAVE_CONFIGURABLE;
 			DUK_ASSERT(DUK_PROPDESC_FLAG_WRITABLE == DUK_DEFPROP_WRITABLE);
 			DUK_ASSERT(DUK_PROPDESC_FLAG_ENUMERABLE == DUK_DEFPROP_ENUMERABLE);
 			DUK_ASSERT(DUK_PROPDESC_FLAG_CONFIGURABLE == DUK_DEFPROP_CONFIGURABLE);
@@ -716,22 +729,28 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 
 #if !defined(DUK_USE_ES6_OBJECT_PROTO_PROPERTY)
 	DUK_DD(DUK_DDPRINT("delete Object.prototype.__proto__ built-in which is not enabled in features"));
-	(void) duk_hobject_delprop_raw(thr, thr->builtins[DUK_BIDX_OBJECT_PROTOTYPE], DUK_HTHREAD_STRING___PROTO__(thr), DUK_DELPROP_FLAG_THROW);
+	(void) duk_hobject_delprop_raw(thr,
+	                               thr->builtins[DUK_BIDX_OBJECT_PROTOTYPE],
+	                               DUK_HTHREAD_STRING___PROTO__(thr),
+	                               DUK_DELPROP_FLAG_THROW);
 #endif
 
 #if !defined(DUK_USE_ES6_OBJECT_SETPROTOTYPEOF)
 	DUK_DD(DUK_DDPRINT("delete Object.setPrototypeOf built-in which is not enabled in features"));
-	(void) duk_hobject_delprop_raw(thr, thr->builtins[DUK_BIDX_OBJECT_CONSTRUCTOR], DUK_HTHREAD_STRING_SET_PROTOTYPE_OF(thr), DUK_DELPROP_FLAG_THROW);
+	(void) duk_hobject_delprop_raw(thr,
+	                               thr->builtins[DUK_BIDX_OBJECT_CONSTRUCTOR],
+	                               DUK_HTHREAD_STRING_SET_PROTOTYPE_OF(thr),
+	                               DUK_DELPROP_FLAG_THROW);
 #endif
 
 	/* XXX: relocate */
 	duk_push_string(thr,
-			/* Endianness indicator */
+	/* Endianness indicator */
 #if defined(DUK_USE_INTEGER_LE)
 	                "l"
 #elif defined(DUK_USE_INTEGER_BE)
 	                "b"
-#elif defined(DUK_USE_INTEGER_ME)  /* integer mixed endian not really used now */
+#elif defined(DUK_USE_INTEGER_ME) /* integer mixed endian not really used now */
 	                "m"
 #else
 	                "?"
@@ -746,89 +765,85 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 	                "?"
 #endif
 	                " "
-			/* Packed or unpacked tval */
+	/* Packed or unpacked tval */
 #if defined(DUK_USE_PACKED_TVAL)
 	                "p"
 #else
 	                "u"
 #endif
 #if defined(DUK_USE_FASTINT)
-			"f"
-#endif
-			" "
-			/* Low memory/performance options */
-#if defined(DUK_USE_STRTAB_PTRCOMP)
-			"s"
-#endif
-#if !defined(DUK_USE_HEAPPTR16) && !defined(DUK_DATAPTR16) && !defined(DUK_FUNCPTR16)
-			"n"
-#endif
-#if defined(DUK_USE_HEAPPTR16)
-			"h"
-#endif
-#if defined(DUK_USE_DATAPTR16)
-			"d"
-#endif
-#if defined(DUK_USE_FUNCPTR16)
-			"f"
-#endif
-#if defined(DUK_USE_REFCOUNT16)
-			"R"
-#endif
-#if defined(DUK_USE_STRHASH16)
-			"H"
-#endif
-#if defined(DUK_USE_STRLEN16)
-			"S"
-#endif
-#if defined(DUK_USE_BUFLEN16)
-			"B"
-#endif
-#if defined(DUK_USE_OBJSIZES16)
-			"O"
-#endif
-#if defined(DUK_USE_LIGHTFUNC_BUILTINS)
-			"L"
-#endif
-#if defined(DUK_USE_ROM_STRINGS) || defined(DUK_USE_ROM_OBJECTS)
-			/* XXX: This won't be shown in practice now
-			 * because this code is not run when builtins
-			 * are in ROM.
-			 */
-			"Z"
-#endif
-#if defined(DUK_USE_LITCACHE_SIZE)
-			"l"
+	                "f"
 #endif
 	                " "
-			/* Object property allocation layout */
-#if defined(DUK_USE_HOBJECT_LAYOUT_1)
-			"p1"
-#elif defined(DUK_USE_HOBJECT_LAYOUT_2)
-			"p2"
-#elif defined(DUK_USE_HOBJECT_LAYOUT_3)
-			"p3"
-#else
-			"p?"
+	/* Low memory/performance options */
+#if defined(DUK_USE_STRTAB_PTRCOMP)
+	                "s"
 #endif
-			" "
-			/* Alignment guarantee */
+#if !defined(DUK_USE_HEAPPTR16) && !defined(DUK_DATAPTR16) && !defined(DUK_FUNCPTR16)
+	                "n"
+#endif
+#if defined(DUK_USE_HEAPPTR16)
+	                "h"
+#endif
+#if defined(DUK_USE_DATAPTR16)
+	                "d"
+#endif
+#if defined(DUK_USE_FUNCPTR16)
+	                "f"
+#endif
+#if defined(DUK_USE_REFCOUNT16)
+	                "R"
+#endif
+#if defined(DUK_USE_STRHASH16)
+	                "H"
+#endif
+#if defined(DUK_USE_STRLEN16)
+	                "S"
+#endif
+#if defined(DUK_USE_BUFLEN16)
+	                "B"
+#endif
+#if defined(DUK_USE_OBJSIZES16)
+	                "O"
+#endif
+#if defined(DUK_USE_LIGHTFUNC_BUILTINS)
+	                "L"
+#endif
+#if defined(DUK_USE_ROM_STRINGS) || defined(DUK_USE_ROM_OBJECTS)
+	                /* XXX: This won't be shown in practice now
+	                 * because this code is not run when builtins
+	                 * are in ROM.
+	                 */
+	                "Z"
+#endif
+#if defined(DUK_USE_LITCACHE_SIZE)
+	                "l"
+#endif
+	                " "
+	/* Object property allocation layout */
+#if defined(DUK_USE_HOBJECT_LAYOUT_1)
+	                "p1"
+#elif defined(DUK_USE_HOBJECT_LAYOUT_2)
+	                "p2"
+#elif defined(DUK_USE_HOBJECT_LAYOUT_3)
+	                "p3"
+#else
+	                "p?"
+#endif
+	                " "
+	/* Alignment guarantee */
 #if (DUK_USE_ALIGN_BY == 4)
-			"a4"
+	                "a4"
 #elif (DUK_USE_ALIGN_BY == 8)
-			"a8"
+	                "a8"
 #elif (DUK_USE_ALIGN_BY == 1)
-			"a1"
+	                "a1"
 #else
 #error invalid DUK_USE_ALIGN_BY
 #endif
-			" "
-			/* Architecture, OS, and compiler strings */
-	                DUK_USE_ARCH_STRING
-			" "
-	                DUK_USE_OS_STRING
-			" "
-	                DUK_USE_COMPILER_STRING);
+	                " "
+	                /* Architecture, OS, and compiler strings */
+	                DUK_USE_ARCH_STRING " " DUK_USE_OS_STRING " " DUK_USE_COMPILER_STRING);
 	duk_xdef_prop_stridx_short(thr, DUK_BIDX_DUKTAPE, DUK_STRIDX_ENV, DUK_PROPDESC_FLAGS_WC);
 
 	/*
@@ -845,7 +860,8 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 #if defined(DUK_USE_DEBUG_LEVEL) && (DUK_USE_DEBUG_LEVEL >= 1)
 	for (i = 0; i < DUK_NUM_ALL_BUILTINS; i++) {
 		DUK_DD(DUK_DDPRINT("built-in object %ld after initialization and compacting: %!@iO",
-		                   (long) i, (duk_heaphdr *) duk_require_hobject(thr, i)));
+		                   (long) i,
+		                   (duk_heaphdr *) duk_require_hobject(thr, (duk_idx_t) i)));
 	}
 #endif
 
@@ -858,13 +874,13 @@ DUK_INTERNAL void duk_hthread_create_builtin_objects(duk_hthread *thr) {
 	duk_set_top(thr, 0);
 	DUK_ASSERT_TOP(thr, 0);
 }
-#endif  /* DUK_USE_ROM_OBJECTS */
+#endif /* DUK_USE_ROM_OBJECTS */
 
 DUK_INTERNAL void duk_hthread_copy_builtin_objects(duk_hthread *thr_from, duk_hthread *thr_to) {
 	duk_small_uint_t i;
 
 	for (i = 0; i < DUK_NUM_BUILTINS; i++) {
 		thr_to->builtins[i] = thr_from->builtins[i];
-		DUK_HOBJECT_INCREF_ALLOWNULL(thr_to, thr_to->builtins[i]);  /* side effect free */
+		DUK_HOBJECT_INCREF_ALLOWNULL(thr_to, thr_to->builtins[i]); /* side effect free */
 	}
 }
